# bootstrap_like_breakpoints: BSBreakPoints

## Post All Questions on StackOverflow, and tag @CatTrain (user:16200950)
https://stackoverflow.com/
<br />

## Importing:
### YAML:
```dart
bootstrap_like_breakpoints: ^0.0.1
```

### Dart:
```dart
import 'package:bootstrap_like_breakpoints/bootstrap_like_breakpoints.dart';
```
## A class with static methods and members. Holds the definitions for:
- <code>_breakPointLabels</code>
    - The labels for breakpoints:
        - ''
        - sm
        - md
        - lg
        - lx
        - xxl
- <code>_breakPoints</code>
    - The widths at which breaks are triggered:
        - '' < 576px
        - sm >= 576px
        - md >= 768px
        - lg >= 992px
        - xl >= 1200px
        - xxl >= 1400px
- <code>_containerWidths</code>
    - The width a container is at a particular breakpoint:
        - '': parent width
        - sm: 540px
        - md: 720px
        - lg: 960px
        - xl: 1140px
        - xxl: 1320px
- <code>_textTypes</code>
    - The types of text this class has values for
        - h1
        - h2
        - h3
        - h4
        - h5
        - h6
        - p
- <code>_textTypesAndSizes</code>
    - A map containing the small and large text sizes for the text that are a <code>_textTypes</code> 
<br />

## The class also has static methods:
- <code>Map<String, double> getBreakPoints() </code>
    - Returns the <code>_breakPoints</code>
- <code>double getContainerWidth(String key)</code>
    - Returns a container width based on the breakpoint label passed as a key
- <code>static Map<String, double> getContainerWidths()</code>
    - Returns <code>_containerWidths</code>
- <code>List\<String> getBreakPointLabels()</code>
    - Returns <code>_breakPointLabels</code>
- <code>dynamic valueBasedOnBreakPoint({required BuildContext context, required Map<String, dynamic> map,})</code>
    - Returns a value based on the passed map, and current breakpoint
    - The passed context is the current context you call the function from
    - **All breakpoints must be specified:**
        - ''
        - sm
        - md
        - lg
        - xl
        - xxl
    - Example:
    ```dart
    BSContainer(
        children: <Widget>[
            BSRow(
                children: <BSColumn>[
                    BSColumn(
                        children: <Widget>[
                            Builder(
                              builder: (context) {
                                return BSBreakPoints.valueBasedOnBreakPoint(
                                  context: context,
                                  map: const <String, Text>{
                                    "": Text("Smallest"),
                                    "sm": Text("SM"),
                                    "md": Text("MD"),
                                    "lg": Text("LG"),
                                    "xl": Text("XL"),
                                    "xxl": Text("XXL"),
                                  },
                                );
                              },
                            ),
                        ],
                    ),
                ],
            ),
        ],
    ),
    ```
- <code>dynamic valueBasedOnBreakPointFromDefinedWidth({required double width, required Map\<String, dynamic> map,}) </code>
    - same as <code>valueBasedOnBreakPoint</code> but instead of getting the width to determine the breakpoint from the context, the width is passed as a double.
    ```dart
    BSContainer(
        children: <Widget>[
            BSRow(
                children: <BSColumn>[
                    BSColumn(
                        children: <Widget>[
                            Builder(
                              builder: (context) {
                                return BSBreakPoints.valueBasedOnBreakPointFromDefinedWidth(
                                  MediaQuery.of(context).size.width,
                                  map: const <String, Text>{
                                    "": Text("Smallest"),
                                    "sm": Text("SM"),
                                    "md": Text("MD"),
                                    "lg": Text("LG"),
                                    "xl": Text("XL"),
                                    "xxl": Text("XXL"),
                                  },
                                );
                              },
                            ),
                        ],
                    ),
                ],
            ),
        ],
    ),
    ```
- <code>String currentBreakPointLabel(BuildContext context)</code>
    - Returns the current <code>_breakPointLabels</code> based on the passed context width
- <code>double columnWidthFromBreakPointTriggers({required double maxWidth, required double screenWidth, required List\<String> breakPointTriggers,})</code>
    - Returns the width a column should be based on the passed screenWidth, the max width, and breakpoint triggers
    - For example, when the breakpoint is md, and a breakpoint trigger of col-md-6 is passed the width would be 50% of the container
```dart
BSBreakPoints.columnWidthFromBreakPointTriggers(
    maxWidth: 1200,
    screenWidth: MediaQuery.of(context).size.width,
    breakPointTriggers: <String>[
        "col-md-6",
    ],
);
```
- <code>static double getTextFontSize(BuildContext context, String textType, {double small = -1, double large = -1,})</code>
    - Returns the size a text type should be based on the screen size. Can have a custom small and or large size passed, otherwise the default large and small sizes are used.
```dart
BSBreakPoints.getTextFontSize(
    context,
    "p",
    small: -14,
    large: 25,
),
```
